@@ -52,6 +52,6 @@ LL <- Conf.Limits$Lower.Limit/sqrt(N)
 UL <- Conf.Limits$Upper.Limit/sqrt(N)
 
 Result <- list(Lower.Conf.Limit.Standardized.Mean=LL, Standardized.Mean=SM, Upper.Conf.Limit.Standardized.Mean=UL)
-print(paste("The", 1-(alpha.lower+alpha.upper),"confidence limits for the standardized mean are given as:"))
+# print(paste("The", 1-(alpha.lower+alpha.upper),"confidence limits for the standardized mean are given as:"))
 return(Result)
 }
